<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sun Aug 02 2020 02:09:57 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed #SICKRAGE-APP-5RS - AttributeError sickrage.providers in cookie_login Fixed #SICKRAGE-APP-5SB - AttributeError sickrage.core.webserver.handlers.root in handle_post Fixed #SICKRAGE-APP-5S8 - RuntimeError threading in start Fixed #SICKRAGE-APP-5RJ - TypeError sickrage.core.version_updater in _git_cmd Fixed #SICKRAGE-APP-5RM - ConnectionError requests.adapters in send Downgraded error to warning before SystemExit raised due to corrupt config detected
  ([34521b84](https://gitlab-ci-token:we2FNycBaDu3WmPLUwXn@git.sickrage.ca/SiCKRAGE/sickrage/commit/34521b84e2e7abedff8e8bdb34f8210a8172bedc))




